@@ -4,5 +4,5 @@ globalVariables(c('top', 'buttonsFrame', 'optionsFrame', 'catalogVariable',
  'modeltypeVariable', 'ordertypeFrame', 'ordertypeVariable', 'outerOperatorsFrame',
  'positiontypeFrame', 'positiontypeVariable', 'responsetypeFrame',
  'responsetypeVariable', 'rhsVariable', 'scoretypeFrame', 'scoretypeVariable',
- 'subsetFrame', 'subsetVariable', 'xBox', 'yesVariable'))
+ 'subsetFrame', 'subsetVariable', 'xBox', 'yesVariable', 'nrowsValue'))
 
